# DQCRT 2021 Test Cases

## Introduction

This is a XBRL International style test suite to test FASB DQCRT/2021 rules implementations against all us-gaap/2020 filings published in 2020, to ascertain that the validator produces expected results.

The test cases are in the standard XBRL International test case format,  used by the XII OIM suite (and many others).

The test cases are split into 16 files so they can be run on an 8 or 16 core server in parallel (it takes about 2.5 hours), they can be re-partitioned as applicable to the testing configuration.

The expected results have been verified by XBRL-US working in conjunction with FASB and using the XBRL-US implementation of the same rule set.

Running the suite with us-gaap/2020 filings against DQCRT/2021 requires a non-production mode of the validator (because EDGAR only applies the 2021 rules to 2021 filings).  (Arelle parameters for that are described below.)

## Testcase file format

The testcase file is a declarative representation that organizes the tests in a way that a test harness can run the tests.

The testcase element is the root element for a set of individual variations.

The testcase contains these elements:

* creator
  * name
  * email
* number:  Testcase number (when part of a larger suite)
* description
* variation:  A single specific test to perform and its expected results (for DQCRT/2021 rules testing).
  * name: a brief name for test cases.
  * description: the form type of the filing, name of company, accession number, date filed
  * data
      * instance: Specifies public URL of accession zip file which contains the filing.  The validating tool loads the inline document set or traditional instance document contained in that zip file.
  * result: Contains expected error codes to be issued when testing the subject instance aginst the DQCRT/2021 rules.  The attribute, blockedMessageCodes, specifies a negating regular expression which only allows message codes for DQCRT, in the format used by XBRL-US, so that all other warnings and messages are not matched against expected results.  For example a validator might report warning messages about hidden facts eligible for transformation, these would be filtered out by that regular expression.
      * error: Specifies the code expected (note that in EDGAR production DQCRT severities are warnings).  The Error is a code, in the format DQC.US.rule.ruleElementId, e.g. DQC.US.0048.7482 means a DQC warning, for US-GAAP (vs IFRS), for rule 0048, for rule element ID 7482.  This code format is used for testing and not reported in this format in the EDGAR production system.

### Operation with Arelle

A shell script is available which runs 16 parallel suite portions and a second shell script merges the test case results file.

Parameters unique to this run are:

*  --disclosureSystem efm-preview-dqcrt-testing: to run DQCRT/2021 rules on us-gaap/2020 filings in this non-production test mode
*  --testcaseResultsCaptureWarnings: to capture warnings in the testcase's error log
*  --testcaseResultOptions match-all: to require that all result error elements are matched (whereas the default behavior is to match-any, as in an "or" condition instead of an "and" condition).
