#!/bin/bash

# Run FASB DQCRT taxonomy tests 
#
# Tests DQCRT/2021 against 16,818 us-gaap/2020 filings
#
# Assumes 16 core cpu to run in 2.5 hrs
#
# Results have been verified by XBRL-US against their databasee of results
#
# Requires arelle disclosure system efm-preview-dqcrt-testing
#
# Result report files merged by script mergeEFMDQC2020TestsOut.sh

ARELLECMDLINESRC=/home/arelle/edgr213/arelleCmdLine.py
PYTHON=python3.7
PLUGINS='validate/EFM|inlineXbrlDocumentSet'
EFM_VAL=efm-pragmatic
EFM_VAL=efm-preview-dqcrt-testing

rm -f out/EFM-DQC-2020-*

for f in $(seq 1 `ls DQC-2020-test-*.xml|wc -l`)
do
	TESTCASESROOT=DQC-2020-test-${f}.xml
	f2dig=$(printf "%02d" ${f})
	OUTPUTLOGFILE=out/EFM-DQC-2020-log-${f2dig}.log
	OUTPUTERRFILE=out/EFM-DQC-2020-err-${f2dig}.txt
	OUTPUTCSVFILE=out/EFM-DQC-2020-report-${f2dig}.csv
	TESTCASESINDEXFILE=$TESTCASESROOT

	$PYTHON $ARELLECMDLINESRC --file "$TESTCASESINDEXFILE" --noCertificateCheck --plugins $PLUGINS --disclosureSystem $EFM_VAL --validate --testcaseResultOptions match-all --csvTestReport "$OUTPUTCSVFILE" --testcaseResultsCaptureWarnings --logFile "$OUTPUTLOGFILE" 2>  "$OUTPUTERRFILE" &
	echo "$! " >> out/EFM-DQC-2020-PIDs
done
